# fa6-icons


<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This module provides the free icons from [Font
Awesome](https://fontawesome.com/) v6 in a python-friendly form.

The actual SVGs and associated data are licensed on the same terms as
the originals – this package only adds a little on top to make them
easier to use from Python.

## Install

``` sh
pip install fa6_icons
```

…or…

``` sh
conda install -c fastai fa6_icons
```

## How to use

Two objects are provided, `svgs` and `dims`.

``` python
from fa6_icons import svgs,dims
```

These are both [AttrDict](https://fastcore.fast.ai/basics.html#attrdict)
objects, which behave as dicts, but can also be accessed with
dotted-attrs. They contain the same keys. To search them, use standard
python dict approaches, e.g:

``` python
[o for o in svgs if 'addr' in o]
```

    ['address_book', 'address_card']

Each style is available as a key for each SVG and dims entry, e.g:

``` python
dims.address_card
```

``` json
{'regular': (512, 576), 'solid': (512, 576)}
```

In a notebook environment, SVGs are displayed:

``` python
svgs.address_card.regular
```

<div style="max-width: 150px; width: 100%;"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 576 512"><path d="M512 80c8.8 0 16 7.2 16 16l0 320c0 8.8-7.2 16-16 16L64 432c-8.8 0-16-7.2-16-16L48 96c0-8.8 7.2-16 16-16l448 0zM64 32C28.7 32 0 60.7 0 96L0 416c0 35.3 28.7 64 64 64l448 0c35.3 0 64-28.7 64-64l0-320c0-35.3-28.7-64-64-64L64 32zM208 256a64 64 0 1 0 0-128 64 64 0 1 0 0 128zm-32 32c-44.2 0-80 35.8-80 80c0 8.8 7.2 16 16 16l192 0c8.8 0 16-7.2 16-16c0-44.2-35.8-80-80-80l-64 0zM376 144c-13.3 0-24 10.7-24 24s10.7 24 24 24l80 0c13.3 0 24-10.7 24-24s-10.7-24-24-24l-80 0zm0 96c-13.3 0-24 10.7-24 24s10.7 24 24 24l80 0c13.3 0 24-10.7 24-24s-10.7-24-24-24l-80 0z"/></svg></div>

To make attr access more convenient, hyphens are replaced with
underscores, and icon names starting with a digit are prefixed with an
underscore.

Use `width` to view the svg in a notebook with a different width (it
defaults to 300px).

``` python
svgs._9.solid.width(25)
```

<div style="max-width: 25px; width: 100%;"><svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512"><path d="M64 192a96 96 0 1 0 192 0A96 96 0 1 0 64 192zm87.5 159.8C67.1 347.4 0 277.5 0 192C0 103.6 71.6 32 160 32s160 71.6 160 160c0 2.6-.1 5.3-.2 7.9c-1.7 35.7-15.2 70-38.4 97.4l-145 171.4c-11.4 13.5-31.6 15.2-45.1 3.8s-15.2-31.6-3.8-45.1l63.9-75.6z"/></svg></div>

When stringified, the SVG text is returned:

``` python
print(svgs._9.solid)
```

    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 320 512"><path d="M64 192a96 96 0 1 0 192 0A96 96 0 1 0 64 192zm87.5 159.8C67.1 347.4 0 277.5 0 192C0 103.6 71.6 32 160 32s160 71.6 160 160c0 2.6-.1 5.3-.2 7.9c-1.7 35.7-15.2 70-38.4 97.4l-145 171.4c-11.4 13.5-31.6 15.2-45.1 3.8s-15.2-31.6-3.8-45.1l63.9-75.6z"/></svg>
